==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/dialout/dialout.pm <==
/* _dict.cc 25/04/1998 11.42.10 */
/* diald.cc 07/08/2000 00.31.06 */
PUBLIC void PPPONE::setdialdpidpath (char *pidpath);
PUBLIC void PPPONE::setdialdconfpath (char *diapath);
PUBLIC void PPPONE::setfifopath (char *diapath);
PRIVATE void PPPONE::setupdiald (int id, SSTRING&setup);
PUBLIC int PPPONE::setupdiald (int id);
PUBLIC PROC *PPPONE::getdialdproc (void);
PUBLIC void PPPONE::dialdcleanup (void);
PUBLIC int PPPONE::killdiald (void);
PUBLIC int PPPONE::startdiald (int id);
PUBLIC int PPPONE::connect_diald (void);
PUBLIC int PPPONE::disconnect_diald (void);
/* dialout.cc 28/08/2000 18.12.20 */
PUBLIC MODULE_dialout::MODULE_dialout (void);
PUBLIC void MODULE_dialout::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_dialout::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_dialout::dohtml (const char *key);
PUBLIC int MODULE_dialout::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_dialout::usage (SSTRINGS&tb);
PUBLIC int MODULE_dialout::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_dialout::probe (int level, int target, bool);
/* ppp.cc 28/08/2000 16.11.52 */
PRIVATE int PPPONE::lcpecho_parse (int &delay, int &retry);
PRIVATE int PPPONE::lcpecho_valid (void);
PRIVATE int PPPONE::validate_edit (SSTRING&baudstr, SSTRING&oldname);
PRIVATE void PPPONE::setdia_iproute (DIALOG&dia, int no);
PUBLIC int PPPONE::edit (void);
PUBLIC CONFIG_FILE_PPPLIST::CONFIG_FILE_PPPLIST (void);
PUBLIC int CONFIG_FILE_PPPLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_PPPLIST::extract (SSTREAM&ss);
/* pppcon.cc 07/08/2000 00.27.52 */
PRIVATE void PPPONE::setipparam (char *str);
PRIVATE void PPPONE::setipxparam (char *str);
PRIVATE int PPPONE::setpppchat (char *pathchat_sh);
PRIVATE void PPPONE::setpapchap (char *pppopt, PRIVILEGE *priv);
PRIVATE int PPPONE::connect_ppp (bool fore, PRIVILEGE *priv);
PRIVATE int PPPONE::connect_pppssh (int);
PUBLIC int PPPONE::getpppd_info (char pppdev[8]);
PUBLIC int PPPONE::getpppd_pid (void);
PRIVATE int PPPONE::disconnect_ppp (void);
PRIVATE int PPPONE::connect_plip (void);
PRIVATE int PPPONE::disconnect_plip (void);
PRIVATE int PPPONE::connect_slip (int);
PRIVATE int PPPONE::disconnect_slip (void);
PUBLIC int PPPONE::connect (bool fore);
PUBLIC int PPPONE::disconnect (void);
PUBLIC int PPPONE::setroutes (const char *cmd_suffix);
PUBLIC int PPPONE::postconnect (const char *dev);
PUBLIC int PPPONE::predisconnect (const char *);
PUBLIC void PPPONE::delpidfile (void);
/* pppdial.cc 21/12/1999 22.03.34 */
PRIVATE void PPPONE::setuptbdb (void);
PRIVATE void PPPONE::opencfg (void);
PUBLIC PPPONE::PPPONE (const char *_name);
PUBLIC PPPONE::~PPPONE (void);
PUBLIC int PPPONE::save (void);
PUBLIC int PPPONE::getusetype (void);
PROTECTED void PPPONE::del (const char *_name);
/* pppmisc.cc 25/04/1998 11.51.36 */
PUBLIC PPPIPROUTE::PPPIPROUTE (void);
PUBLIC PPPIPROUTE::PPPIPROUTE (const char *s);
PUBLIC PPPIPROUTE *PPPIPROUTES::getitem (int no);
PUBLIC int PPPIPROUTES::empty (void);
/* pppwait.cc 23/08/2000 01.36.48 */
PRIVATE void PPPONE::setfifowait (char *path);
PRIVATE int PPPONE::pppwait_cmd (const char *cmd);
PRIVATE int PPPONE::updsecrets (PRIVILEGE *priv);
/* pppwatch.cc 28/08/2000 17.05.02 */

==> linuxconf-1.26r2.src.tar.gz: linuxconf-1.26r2/modules/dialout/dialout.pm <==
/* _dict.cc 25/04/1998 11.42.10 */
/* diald.cc 07/08/2000 00.31.06 */
PUBLIC void PPPONE::setdialdpidpath (char *pidpath);
PUBLIC void PPPONE::setdialdconfpath (char *diapath);
PUBLIC void PPPONE::setfifopath (char *diapath);
PRIVATE void PPPONE::setupdiald (int id, SSTRING&setup);
PUBLIC int PPPONE::setupdiald (int id);
PUBLIC PROC *PPPONE::getdialdproc (void);
PUBLIC void PPPONE::dialdcleanup (void);
PUBLIC int PPPONE::killdiald (void);
PUBLIC int PPPONE::startdiald (int id);
PUBLIC int PPPONE::connect_diald (void);
PUBLIC int PPPONE::disconnect_diald (void);
/* dialout.cc 10/10/2000 20.41.26 */
PUBLIC MODULE_dialout::MODULE_dialout (void);
PUBLIC void MODULE_dialout::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_dialout::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_dialout::dohtml (const char *key);
PUBLIC int MODULE_dialout::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_dialout::usage (SSTRINGS&tb);
PUBLIC int MODULE_dialout::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_dialout::probe (int level, int target, bool);
/* ppp.cc 07/11/2000 10.46.04 */
PRIVATE int PPPONE::lcpecho_parse (int &delay, int &retry);
PRIVATE int PPPONE::lcpecho_valid (void);
PRIVATE int PPPONE::validate_edit (SSTRING&baudstr,
	 SSTRING&oldname,
	 int &nof,
	 int field_name,
	 int field_device,
	 int field_lcpecho,
	 int field_ssh);
PRIVATE void PPPONE::setdia_iproute (DIALOG&dia, int no);
PUBLIC int PPPONE::edit (void);
PUBLIC void PPPONE::control (void);
PUBLIC CONFIG_FILE_PPPLIST::CONFIG_FILE_PPPLIST (void);
PUBLIC int CONFIG_FILE_PPPLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_PPPLIST::extract (SSTREAM&ss);
/* pppcon.cc 07/08/2000 00.27.52 */
PRIVATE void PPPONE::setipparam (char *str);
PRIVATE void PPPONE::setipxparam (char *str);
PRIVATE int PPPONE::setpppchat (char *pathchat_sh);
PRIVATE void PPPONE::setpapchap (char *pppopt, PRIVILEGE *priv);
PRIVATE int PPPONE::connect_ppp (bool fore, PRIVILEGE *priv);
PRIVATE int PPPONE::connect_pppssh (int);
PUBLIC int PPPONE::getpppd_info (char pppdev[8]);
PUBLIC int PPPONE::getpppd_pid (void);
PRIVATE int PPPONE::disconnect_ppp (void);
PRIVATE int PPPONE::connect_plip (void);
PRIVATE int PPPONE::disconnect_plip (void);
PRIVATE int PPPONE::connect_slip (int);
PRIVATE int PPPONE::disconnect_slip (void);
PUBLIC int PPPONE::connect (bool fore);
PUBLIC int PPPONE::disconnect (void);
PUBLIC int PPPONE::setroutes (const char *cmd_suffix);
PUBLIC int PPPONE::postconnect (const char *dev);
PUBLIC int PPPONE::predisconnect (const char *);
PUBLIC void PPPONE::delpidfile (void);
/* pppdial.cc 21/12/1999 22.03.34 */
PRIVATE void PPPONE::setuptbdb (void);
PRIVATE void PPPONE::opencfg (void);
PUBLIC PPPONE::PPPONE (const char *_name);
PUBLIC PPPONE::~PPPONE (void);
PUBLIC int PPPONE::save (void);
PUBLIC int PPPONE::getusetype (void);
PROTECTED void PPPONE::del (const char *_name);
/* pppmisc.cc 25/04/1998 11.51.36 */
PUBLIC PPPIPROUTE::PPPIPROUTE (void);
PUBLIC PPPIPROUTE::PPPIPROUTE (const char *s);
PUBLIC PPPIPROUTE *PPPIPROUTES::getitem (int no);
PUBLIC int PPPIPROUTES::empty (void);
/* pppwait.cc 23/08/2000 01.36.48 */
PRIVATE void PPPONE::setfifowait (char *path);
PRIVATE int PPPONE::pppwait_cmd (const char *cmd);
PRIVATE int PPPONE::updsecrets (PRIVILEGE *priv);
/* pppwatch.cc 28/08/2000 17.05.02 */
